@@ -1,6 +1,6 @@
 /*
 
-  $Id: gnokii.c,v 1.490 2008/08/11 10:50:41 pkot Exp $
+  $Id: gnokii.c,v 1.493 2009/02/04 08:56:58 pkot Exp $
 
   G N O K I I
 
@@ -212,8 +212,9 @@ static void version(void)
 	fprintf(stderr, _("Copyright (C) Hugh Blemings <hugh@blemings.org>, 1999, 2000\n"
 			  "Copyright (C) Pavel Janik ml. <Pavel.Janik@suse.cz>, 1999, 2000\n"
 			  "Copyright (C) Pavel Machek <pavel@ucw.cz>, 2001\n"
-			  "Copyright (C) Pawel Kot <pkot@linuxnews.pl>, 2001-2006\n"
+			  "Copyright (C) Pawel Kot <gnokii@gmail.com>, 2001-2009\n"
 			  "Copyright (C) BORBELY Zoltan <bozo@andrews.hu>, 2002\n"
+			  "Copyright (C) Daniele Forsi <daniele@forsi.it>, 2004-2009\n"
 			  "gnokii is free software, covered by the GNU General Public License, and you are\n"
 			  "welcome to change it and/or distribute copies of it under certain conditions.\n"
 			  "There is absolutely no warranty for gnokii.  See GPL for details.\n"
@@ -378,9 +379,6 @@ static int checkargs(int opt, struct gnokii_arg_len gals[], int argc, int has_ar
 #ifndef WIN32
 static int foogle(int argc, char *argv[])
 {
-	/* Fill in what you would like to test here... */
-	/* remember to call businit(); if you need to communicate with your phone */
-	return 0;
 }
 #endif
 
@@ -710,6 +708,7 @@ static int parse_options(int argc, char *argv[])
 		{ OPT_DELETEFILE,        1, 1, 0 },
 		{ OPT_DELETEFILEBYID,    1, 1, 0 },
 		{ OPT_SHELL,             0, 0, 0 },
+		{ OPT_FOOGLE,            0, 0, 0 },
 		{ 0, 0, 0, 0 },
 	};
 
@@ -1082,7 +1081,7 @@ int shell(gn_data *data, struct gn_statemachine *state)
 			else
 				len = strlen(input);
 			if (len > 0)
-				argv[argc++] = strndup(input, len);
+				argv[argc++] = strdup(input);
 			input = tmp;
 		} while (input);
 		argv[argc] = NULL;
